from yaml.loader import SafeLoader


class SafeLineLoader(SafeLoader):
    def construct_mapping(self, node, deep=False):
        mapping = super(SafeLineLoader, self).construct_mapping(node, deep=deep)
        # Add 1 so line numbering starts at 1
        mapping['__line__'] = node.start_mark.line + 1
        return mapping

def load_yaml_as_document_with_count(entry):
    with open(entry) as file:
        return yaml.load(file,Loader=SafeLineLoader)


import unittest
import os
from tjauto import cli_util

class TestCli(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        os.system("rm ./tests/assets/cli/NEW_FILE")

    def test_goto_and_exec(self):
        self.assertTrue( not os.path.exists("./tests/assets/cli/NEW_FILE"))
        cli_util.goto_and_exec("./tests/assets/cli","touch NEW_FILE")
        self.assertTrue( os.path.exists("./tests/assets/cli/NEW_FILE"))



import os

def read_dir_and_handle(start_path, need_handle, handler):
    entries = os.listdir(start_path)
    for entry in entries:
        dir_path = os.path.join(start_path,entry)
        if os.path.isdir(dir_path) and need_handle(dir_path):
            handler(dir_path)

def read_dict_and_handle_recursive(start_path, dir_name, file_need_handle, file_handler):
    # print("here start" + start_path)
    entries = os.listdir(start_path)
    for entry in entries:
        if os.path.isdir(os.path.join(start_path,entry)):
            # print("here dir")
            read_dict_file(os.path.join(start_path,entry), entry,file_need_handle, file_handler)   
        elif os.path.isfile(os.path.join(start_path,entry)) and need_handle(entry):
            file_handler(os.path.join(start_path,entry), entry, dir_name)    


def get_all_sub_dir(path):
    entries = os.listdir(path)
    return list(filter(lambda x: os.path.isdir(os.path.join(path,x)), entries))
 



import unittest
from tjauto import json_util

class TestJSON(unittest.TestCase):
    def test_read_json_file_has_array(self):
        json_data = json_util.read_json_file("./tests/assets/json/string_array.json")
        self.assertEqual(json_data, ['a','b'])
    def test_read_json_file_has_object(self):
        json_data = json_util.read_json_file("./tests/assets/json/object.json")
        self.assertEqual(json_data, {"name": "T,J", "phones": ["1234567890", "0987654321"]})


if __name__ == '__main__':
    unittest.main()


import unittest
from tjauto import github_util

class TestGitHub(unittest.TestCase):
    def test_get_from_html_url(self):
        repo_name = github_util.get_repo_name("https://github.com/jtong/tjauto")
        self.assertEqual(repo_name, "tjauto")

    def test_get_from_https_clone_url(self):
        repo_name = github_util.get_repo_name("https://github.com/jtong/tjauto.git")
        self.assertEqual(repo_name, "tjauto")

    def test_get_from_ssh_clone_url(self):
        repo_name = github_util.get_repo_name("git@github.com:jtong/tjauto.git")
        self.assertEqual(repo_name, "tjauto")



import json 

def read_json_file(path):
    with open(path, "r") as repos_json_file:
        return json.loads(repos_json_file.read())

def handle_each_in_json_array(json_object, callback):
    for x in repos_json:
        callback(x)

def is_json_file(file_name):
    return file_name.endswith(".json")
